@@ -1,6 +1,6 @@
 
 import React, {
-  PropTypes,
+  Component,
 } from 'react'
 import {
   View,
